"use strict";

exports.extractType = extractType;
exports.validateType = validateType;
Object.defineProperty(exports, "__esModule", {
    value: true
});
"use strict";

var isNullOrUndefined = require("./helpers").isNullOrUndefined;

/**
 * RegExp that is used to extract the generic type name
 * out of an array.
 */
var genericExpr = /array<(\w+)>/i;

exports.genericExpr = genericExpr;

function extractType(type) {
    if (genericExpr.test(type)) {
        return genericExpr.exec(type)[1];
    }

    return type;
}

/**
 * Validators for basic JS types.
 */
var typeValidators = {
    string: function string(val) {
        return isNullOrUndefined(val) || typeof val === "string";
    },

    number: function number(val) {
        return isNullOrUndefined(val) || typeof val === "number" || !isNaN(parseFloat(val));
    },

    integer: function integer(val) {
        return isNullOrUndefined(val) || Number.isInteger(parseFloat(val));
    },

    array: function array(val) {
        return isNullOrUndefined(val) || Array.isArray(val);
    },

    date: function date() {
        return true; // TODO
    }
};

function validateType(val, type) {
    // Remove generics from the picture.
    type = type.split("<")[0];

    return typeValidators[type](val);
}